# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
from .spreadsheet_document_settings import SpreadsheetDocumentSettings as SpreadsheetDocumentSettings_a1641229
from .x_function_access import XFunctionAccess as XFunctionAccess_e2000d11

class FunctionAccess(SpreadsheetDocumentSettings_a1641229, XFunctionAccess_e2000d11):
    """
    Service Class

    allows generic access to all spreadsheet functions.
    
    **since**
    
        OOo 3.3

    See Also:
        `API FunctionAccess <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1FunctionAccess.html>`_
    """
    @property
    def IsArrayFunction(self) -> bool:
        """
        specifies whether the function call is performed as array function call.
        
        If set to TRUE, the result of the function call will be calculated similar to array formulas in a spreadsheet document. The return value of the function call will usually be a sequence of sequences containing the values of the resulting array. Example: If the function ABS is called for a 3x2 cell range, the result will be a 3x2 array containing the absolute values of the numbers contained in the specified cell range.
        
        If set to FALSE, the result of the function call will be calculated similar to simple cell formulas in a spreadsheet document. The return value of the function call will usually be a single value. Of course, some functions always return an array, for example the MUNIT function.
        
        For compatibility with older versions, the default value of this property is TRUE.
        
        **since**
        
            OOo 3.3
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.linguistic2
# Libre Office Version: 7.3
from typing_extensions import Literal
from ..lang.event_object import EventObject as EventObject_a3d70b03
from ..uno.x_interface import XInterface as XInterface_8f010a43
import typing
from .x_dictionary_entry import XDictionaryEntry as XDictionaryEntry_49ef0ff5


class DictionaryEvent(EventObject_a3d70b03):
    """
    Struct Class

    represents a dictionary event.
    
    This type of event is used by a dictionary to inform its listeners about changes in its properties or its entry list. It consists of an event type and may supply an affected dictionary entry.

    See Also:
        `API DictionaryEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1linguistic2_1_1DictionaryEvent.html>`_
    """
    typeName: Literal['com.sun.star.linguistic2.DictionaryEvent']

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = ..., nEvent: typing.Optional[int] = ..., xDictionaryEntry: typing.Optional[XDictionaryEntry_49ef0ff5] = ...) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            nEvent (int, optional): nEvent value.
            xDictionaryEntry (XDictionaryEntry, optional): xDictionaryEntry value.
        """


    @property
    def nEvent(self) -> int:
        """
        is the type of event.
        
        This must be the value of a single flag. No combinations are allowed.
        """


    @property
    def xDictionaryEntry(self) -> XDictionaryEntry_49ef0ff5:
        """
        is the affected dictionary entry (if any).
        
        It must be set if an entry was added or deleted, otherwise it should be empty.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Singleton Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.util
# Libre Office Version: 7.3
from .x_macro_expander import XMacroExpander as XMacroExpander_c8360c47


class theMacroExpander(XMacroExpander_c8360c47):
    """
    Singleton Class

    A service that has to deal with macrofied strings will preprocess those strings using the macro expander singleton.
    
    The macro expander singleton is deployed with the application.
    
    This feature is currently used macrofying loader urls with macros defined in uno.ini/unorc bootstrap files. The component loader uses the macro expander singleton to expand those macros. This is a flexible way preprocessing loader urls.

    See Also:
        `API theMacroExpander <https://api.libreoffice.org/docs/idl/ref/singletoncom_1_1sun_1_1star_1_1util_1_1theMacroExpander.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.configuration.backend
from typing_extensions import Literal


class NodeAttribute(object):
    """
    Const

    These values are used to specify the behavior of a node or property in a layer.
    
    The values were chosen so they can be combined with values from SchemaAttribute
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API NodeAttribute <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1NodeAttribute.html>`_
    """
    FINALIZED: Literal[256]
    """
    indicates that a node or property may not be changed or overridden in subsequent layers
    """
    MANDATORY: Literal[512]
    """
    indicates that a set item may not be removed or replaced in subsequent layers.
    """
    READONLY: Literal[1024]
    """
    indicates that a node or property may not be changed in this or subsequent layer.
    """
    FUSE: Literal[2048]
    """
    indicates that contents shall be fused.
    
    Used in XLayerHandler.addOrReplaceNode(), XLayerHandler.addOrReplaceNodeFromTemplate(), XUpdateHandler.addOrReplaceNode(), and XUpdateHandler.addOrReplaceNodeFromTemplate().
    
    **since**
    
        OOo 2.0.3
    """
    MASK: Literal[32512]
    """
    can be used to mask the node attributes from merged attributes
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.linguistic2
from typing_extensions import Literal
import typing
from .x_supported_locales import XSupportedLocales as XSupportedLocales_5bda1056
if typing.TYPE_CHECKING:
    from ..beans.property_values import PropertyValues as PropertyValues_d6470ce6
    from ..lang.locale import Locale as Locale_70d308fa
    from .x_spell_alternatives import XSpellAlternatives as XSpellAlternatives_6ad110bf

class XSpellChecker(XSupportedLocales_5bda1056):
    """
    This interface allows for spell checking.
    
    It is possible to simply check if a word, in a specified language, is correct or additionally, if it was misspelled, some proposals how it might be correctly written.

    See Also:
        `API XSpellChecker <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XSpellChecker.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.linguistic2.XSpellChecker']

    def isValid(self, aWord: str, aLocale: 'Locale_70d308fa', aProperties: 'PropertyValues_d6470ce6') -> bool:
        """
        checks if a word is spelled correctly in a given language.
        
        If aLocale is not supported an IllegalArgumentException exception is raised.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def spell(self, aWord: str, aLocale: 'Locale_70d308fa', aProperties: 'PropertyValues_d6470ce6') -> 'XSpellAlternatives_6ad110bf':
        """
        This method checks if a word is spelled correctly in a given language.
        
        If the language is not supported an IllegalArgumentException exception is raised.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdbcx
from .x_groups_supplier import XGroupsSupplier as XGroupsSupplier_e3410d48
from .x_tables_supplier import XTablesSupplier as XTablesSupplier_e1ad0d23
from .x_users_supplier import XUsersSupplier as XUsersSupplier_d6060cda
from .x_views_supplier import XViewsSupplier as XViewsSupplier_d5cd0cd6

class DatabaseDefinition(XGroupsSupplier_e3410d48, XTablesSupplier_e1ad0d23, XUsersSupplier_d6060cda, XViewsSupplier_d5cd0cd6):
    """
    Service Class

    could be used as an extension for performing data definition tasks on databases, and to control the access rights on database objects.
    
    It may be implemented by a database driver provider, to encapsulate the complexity of data definition, and to give a common way for data definition as the DDL of most DBMS differs.
    
    At least, the access to the tables of a database should be implemented. The implementation of other known database objects like views is optional.
    
    To control the access rights of users, there is the possibility to implement objects like users and groups.

    See Also:
        `API DatabaseDefinition <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdbcx_1_1DatabaseDefinition.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.chart
from typing_extensions import Literal
import typing
from ..frame.x_model import XModel as XModel_7a6e095c
if typing.TYPE_CHECKING:
    from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
    from .x_chart_data import XChartData as XChartData_a3580ade
    from .x_diagram import XDiagram as XDiagram_8e1e0a27
    from ..drawing.x_shape import XShape as XShape_8fd00a3d

class XChartDocument(XModel_7a6e095c):
    """
    manages the chart document.

    See Also:
        `API XChartDocument <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1chart_1_1XChartDocument.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.chart.XChartDocument']

    def attachData(self, xData: 'XChartData_a3580ade') -> None:
        """
        attaches data to the chart.
        
        The given object needs to support interface XChartDataArray.
        
        Since OOo 3.3 if the given object might support interface XComplexDescriptionAccess which allows to set complex hierarchical axis descriptions.
        
        Since OOo 3.4 if the given object might support interface XDateCategories which allows to set date values as x values for category charts.
        
        The given data is copied before it is applied to the chart. So changing xData after this call will have no effect on the chart.
        """
    def getArea(self) -> 'XPropertySet_bc180bfa':
        """
        The area's extent is equal to the document size. If you want to access properties of the background area of the diagram, in which the actual data is represented, you have to change the chart wall which you get from the X3DDisplay.
        """
    def getData(self) -> 'XChartData_a3580ade':
        """
        The returned object supports interface XChartDataArray which can be used to access the concrete data.
        
        Since OOo 3.3 the returned object also supports interface XComplexDescriptionAccess which can be used to access complex hierarchical axis descriptions.
        
        Since OOo 3.4 the returned object also supports interface XDateCategories.
        """
    def getDiagram(self) -> 'XDiagram_8e1e0a27':
        """
        """
    def getLegend(self) -> 'XShape_8fd00a3d':
        """
        """
    def getSubTitle(self) -> 'XShape_8fd00a3d':
        """
        Usually the subtitle is smaller than the main title by default. And it is most commonly placed below the main title by default.
        """
    def getTitle(self) -> 'XShape_8fd00a3d':
        """
        """
    def setDiagram(self, xDiagram: 'XDiagram_8e1e0a27') -> None:
        """
        sets the diagram for the chart document.
        
        Setting a new diagram implicitly disposes the previous diagram.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.style
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from ..container.x_index_replace import XIndexReplace as XIndexReplace_feed0dd7
    from ..container.x_name_container import XNameContainer as XNameContainer_cb90e47
    from ..graphic.x_graphic import XGraphic as XGraphic_a4da0afc
    from .break_type import BreakType as BreakType_9b050ac0
    from .drop_cap_format import DropCapFormat as DropCapFormat_c95f0c4b
    from .graphic_location import GraphicLocation as GraphicLocation_e3ef0d30
    from .line_spacing import LineSpacing as LineSpacing_b1ad0b86
    from .paragraph_adjust import ParagraphAdjust as ParagraphAdjust_e42a0d3a
    from .tab_stop import TabStop as TabStop_860309f6
    from ..table.border_line import BorderLine as BorderLine_a3f80af6
    from ..table.shadow_format import ShadowFormat as ShadowFormat_bb840bdf
    from ..util.color import Color as Color_68e908c5

class ParagraphProperties(ABC):
    """
    Service Class

    describes the style of paragraphs.
    
    **since**
    
        LibreOffice 4.2

    See Also:
        `API ParagraphProperties <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html>`_
    """
    @property
    def ParaInteropGrabBag(self) -> 'typing.Tuple[PropertyValue_c9610c73, ...]':
        """
        Grab bag of paragraph properties, used as a string-any map for interim interop purposes.
        
        This property is intentionally not handled by the ODF filter. Any member that should be handled there should be first moved out from this grab bag to a separate property.
        
        **since**
        
            LibreOffice 4.2
        """
    @property
    def ParaTabStops(self) -> 'typing.Tuple[TabStop_860309f6, ...]':
        """
        specifies the positions and kinds of the tab stops within this paragraph.
        """
    @property
    def BorderDistance(self) -> int:
        """
        contains the distance from the border to the object.
        """
    @property
    def BottomBorder(self) -> 'BorderLine_a3f80af6':
        """
        contains the bottom border of the object.
        """
    @property
    def BottomBorderDistance(self) -> int:
        """
        contains the distance from the bottom border to the object.
        """
    @property
    def BreakType(self) -> 'BreakType_9b050ac0':
        """
        determines the type of break that is applied at the beginning of the table.
        """
    @property
    def ContinueingPreviousSubTree(self) -> bool:
        """
        specifies that a child node of a parent node that is not counted is continuing the numbering of parent's previous node's sub tree.
        
        **since**
        
            OOo 3.0.1
        """
    @property
    def DropCapCharStyleName(self) -> str:
        """
        specifies the character style name for drop caps.
        """
    @property
    def DropCapFormat(self) -> 'DropCapFormat_c95f0c4b':
        """
        specifies whether the first characters of the paragraph are displayed in capital letters and how they are formatted.
        """
    @property
    def DropCapWholeWord(self) -> bool:
        """
        specifies if the property DropCapFormat is applied to the whole first word.
        """
    @property
    def LeftBorder(self) -> 'BorderLine_a3f80af6':
        """
        contains the left border of the object.
        """
    @property
    def LeftBorderDistance(self) -> int:
        """
        contains the distance from the left border to the object.
        """
    @property
    def ListId(self) -> str:
        """
        specifies the id of the list to which the paragraph belongs
        """
    @property
    def ListLabelString(self) -> str:
        """
        allows reading the generated numbering list label.
        
        **since**
        
            OOo 3.0.1
        """
    @property
    def NumberingIsNumber(self) -> bool:
        """
        returns FALSE if the paragraph is part of a numbering, but has no numbering label.
        
        A paragraph is part of a numbering, if a style for a numbering is set - see NumberingStyleName.
        
        If the paragraph is not part of a numbering the property is void.
        """
    @property
    def NumberingLevel(self) -> int:
        """
        specifies the numbering level of the paragraph.
        """
    @property
    def NumberingRules(self) -> 'XIndexReplace_feed0dd7':
        """
        contains the numbering rules applied to this paragraph.
        """
    @property
    def NumberingStartValue(self) -> int:
        """
        specifies the start value for numbering if a new numbering starts at this paragraph.
        """
    @property
    def NumberingStyleName(self) -> str:
        """
        specifies the name of the style for the numbering.
        
        The name must be one of the names which are available via XStyleFamiliesSupplier.
        """
    @property
    def OutlineLevel(self) -> int:
        """
        specifies the outline level to which the paragraph belongs
        
        Value 0 indicates that the paragraph belongs to the body text.
        
        Values [1..10] indicates that the paragraph belongs to the corresponding outline level.
        
        **since**
        
            OOo 3.1
        """
    @property
    def PageDescName(self) -> str:
        """
        If this property is set, it creates a page break before the paragraph it belongs to and assigns the value as the name of the new page style sheet to use.
        """
    @property
    def PageNumberOffset(self) -> int:
        """
        If a page break property is set at a paragraph, this property contains the new value for the page number.
        """
    @property
    def PageStyleName(self) -> str:
        """
        contains the name of the current page style.
        """
    @property
    def ParaAdjust(self) -> 'ParagraphAdjust_e42a0d3a':
        """
        determines the adjustment of a paragraph.
        """
    @property
    def ParaBackColor(self) -> 'Color_68e908c5':
        """
        contains the paragraph background color.
        """
    @property
    def ParaBackGraphic(self) -> 'XGraphic_a4da0afc':
        """
        contains the graphic for the background of a paragraph.
        
        **since**
        
            LibreOffice 6.1
        """
    @property
    def ParaBackGraphicFilter(self) -> str:
        """
        contains the name of the graphic filter for the background graphic of a paragraph.
        """
    @property
    def ParaBackGraphicLocation(self) -> 'GraphicLocation_e3ef0d30':
        """
        contains the value for the position of a background graphic.
        """
    @property
    def ParaBackGraphicURL(self) -> str:
        """
        contains the value of a link for the background graphic of a paragraph.
        
        Note the new behaviour since it this was deprecated: This property can only be set and only external URLs are supported (no more vnd.sun.star.GraphicObject scheme). When an URL is set, then it will load the graphic and set the ParaBackGraphic property.
        """
    @property
    def ParaBackTransparent(self) -> bool:
        """
        This value is TRUE if the paragraph background color is set to transparent.
        """
    @property
    def ParaBottomMargin(self) -> int:
        """
        determines the bottom margin of the paragraph in 100th mm.
        
        The distance between two paragraphs is specified by:
        
        The greater one is chosen.
        """
    @property
    def ParaContextMargin(self) -> bool:
        """
        determines if contextual spacing is used.
        
        If true, the top and bottom margins of the paragraph should not be applied when the previous and next paragraphs have the same style.
        
        **since**
        
            LibreOffice 3.6
        """
    @property
    def ParaExpandSingleWord(self) -> bool:
        """
        determines if single words are stretched.
        
        It is only valid if ParagraphProperties.ParaAdjust and ParagraphProperties.ParaLastLineAdjust are also valid.
        """
    @property
    def ParaFirstLineIndent(self) -> int:
        """
        specifies the indent for the first line.
        """
    @property
    def ParaHyphenationMaxHyphens(self) -> int:
        """
        specifies the maximum number of consecutive hyphens.
        """
    @property
    def ParaHyphenationMaxLeadingChars(self) -> int:
        """
        specifies the minimum number of characters to remain before the hyphen character (when hyphenation is applied).
        """
    @property
    def ParaHyphenationMaxTrailingChars(self) -> int:
        """
        specifies the minimum number of characters to remain after the hyphen character (when hyphenation is applied).
        """
    @property
    def ParaHyphenationNoCaps(self) -> bool:
        """
        Specifies whether words written in CAPS will be hyphenated.
        
        Setting to true will disable hyphenation of words written in CAPS for this paragraph.
        
        **since**
        
            LibreOffice 6.4
        """
    @property
    def ParaIsAutoFirstLineIndent(self) -> bool:
        """
        determines if the first line should be indented automatically.
        """
    @property
    def ParaIsConnectBorder(self) -> bool:
        """
        the property determines if borders set at a paragraph are merged with the next paragraph.
        
        Borders are only merged if they are identical.
        """
    @property
    def ParaIsHyphenation(self) -> bool:
        """
        specifies if automatic hyphenation is applied.
        """
    @property
    def ParaIsNumberingRestart(self) -> bool:
        """
        determines if the numbering rules restart, counting at the current paragraph.
        """
    @property
    def ParaKeepTogether(self) -> bool:
        """
        Setting this property to TRUE prevents page or column breaks between this and the following paragraph.
        
        This feature is useful for preventing title paragraphs to be the last line on a page or column.
        """
    @property
    def ParaLastLineAdjust(self) -> int:
        """
        determines the adjustment of the last line.
        
        It is only valid if ParagraphProperties.ParaAdjust is set to ParagraphAdjust.BLOCK.
        """
    @property
    def ParaLeftMargin(self) -> int:
        """
        determines the left margin of the paragraph in 100th mm.
        """
    @property
    def ParaLineNumberCount(self) -> bool:
        """
        determines if the paragraph is included in the line numbering.
        """
    @property
    def ParaLineNumberStartValue(self) -> int:
        """
        contains the start value for the line numbering.
        """
    @property
    def ParaLineSpacing(self) -> 'LineSpacing_b1ad0b86':
        """
        contains the type of the line spacing of a paragraph.
        """
    @property
    def ParaOrphans(self) -> int:
        """
        specifies the minimum number of lines of the paragraph that have to be at bottom of a page if the paragraph is spread over more than one page.
        """
    @property
    def ParaRegisterModeActive(self) -> bool:
        """
        determines if the register mode is applied to a paragraph.
        
        Remark: Register mode is only used if the register mode property of the page style is switched on.
        """
    @property
    def ParaRightMargin(self) -> int:
        """
        determines the right margin of the paragraph in 100th mm.
        """
    @property
    def ParaShadowFormat(self) -> 'ShadowFormat_bb840bdf':
        """
        determines the type, color, and size of the shadow.
        """
    @property
    def ParaSplit(self) -> bool:
        """
        Setting this property to FALSE prevents the paragraph from getting split into two pages or columns.
        """
    @property
    def ParaStyleName(self) -> str:
        """
        contains the name of the current paragraph style.
        """
    @property
    def ParaTopMargin(self) -> int:
        """
        determines the top margin of the paragraph in 100th mm.
        
        The distance between two paragraphs is specified by:
        
        The greater one is chosen.
        """
    @property
    def ParaUserDefinedAttributes(self) -> 'XNameContainer_cb90e47':
        """
        this property stores xml attributes.
        
        They will be saved to and restored from automatic styles inside xml files.
        """
    @property
    def ParaVertAlignment(self) -> int:
        """
        specifies the vertical alignment of a paragraph.
        """
    @property
    def ParaWidows(self) -> int:
        """
        specifies the minimum number of lines of the paragraph that have to be at top of a page if the paragraph is spread over more than one page.
        """
    @property
    def RightBorder(self) -> 'BorderLine_a3f80af6':
        """
        contains the right border of the object.
        """
    @property
    def RightBorderDistance(self) -> int:
        """
        contains the distance from the right border to the object.
        """
    @property
    def TopBorder(self) -> 'BorderLine_a3f80af6':
        """
        contains the top border of the object.
        """
    @property
    def TopBorderDistance(self) -> int:
        """
        contains the distance from the top border to the object.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
from abc import ABC

class RangeSelectionArguments(ABC):
    """
    Service Class

    contains the arguments for starting the range selection.
    
    **since**
    
        OOo 2.0.3

    See Also:
        `API RangeSelectionArguments <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1RangeSelectionArguments.html>`_
    """
    @property
    def CloseOnMouseRelease(self) -> bool:
        """
        specifies if the range selection is finished when the mouse button is released, after selecting cells.
        """
    @property
    def InitialValue(self) -> str:
        """
        contains the initial value for the range descriptor.
        """
    @property
    def SingleCellMode(self) -> bool:
        """
        specifies if the range selection is limited to a single cell only.
        
        If TRUE, the selection is restricted to a single cell. If FALSE, multiple adjoining cells can be selected. The default value is FALSE.
        
        **since**
        
            OOo 2.0.3
        """
    @property
    def Title(self) -> str:
        """
        contains a title for the operation.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.animations
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing


class Event(object):
    """
    Struct Class

    an event has a source that causes an event to be fired and a trigger that defines under which condition an event should be raised and an offset if the event should be raised a defined amount of time after the event is triggered.

    See Also:
        `API Event <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1animations_1_1Event.html>`_
    """
    typeName: Literal['com.sun.star.animations.Event']

    def __init__(self, Source: typing.Optional[object] = ..., Trigger: typing.Optional[int] = ..., Offset: typing.Optional[object] = ..., Repeat: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            Source (object, optional): Source value.
            Trigger (int, optional): Trigger value.
            Offset (object, optional): Offset value.
            Repeat (int, optional): Repeat value.
        """


    @property
    def Source(self) -> object:
        """
        this is the source for this event.
        """


    @property
    def Trigger(self) -> int:
        """
        this is the trigger that fires this event.
        """


    @property
    def Offset(self) -> object:
        """
        an optional offset in seconds or Timing.INDEFINITE.
        
        This is the timespan between the triggering of the event and actually raising the event
        """


    @property
    def Repeat(self) -> int:
        """
        an option repeat value.
        
        If the Trigger is EventTrigger, this is the number of repeats after which the event is initially raised.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.form
from typing_extensions import Literal
import typing
from .x_grid import XGrid as XGrid_6836089a
from .x_grid_field_data_supplier import XGridFieldDataSupplier as XGridFieldDataSupplier_34aa0f4c
if typing.TYPE_CHECKING:
    from .x_grid_control_listener import XGridControlListener as XGridControlListener_19a70ec1

class XGridControl(XGrid_6836089a, XGridFieldDataSupplier_34aa0f4c):
    """
    specifies (some) functionality provided by a grid control (aka table control)
    
    **since**
    
        OOo 3.1

    See Also:
        `API XGridControl <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1form_1_1XGridControl.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.form.XGridControl']

    def addGridControlListener(self, listener: 'XGridControlListener_19a70ec1') -> None:
        """
        registers a listener which is to be notified about state changes in the grid control
        """
    def removeGridControlListener(self, listener: 'XGridControlListener_19a70ec1') -> None:
        """
        revokes a previously registered grid control listener
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .._pyi.animations.animate_color import AnimateColor as AnimateColor
from .._pyi.animations.animate_motion import AnimateMotion as AnimateMotion
from .._pyi.animations.animate_physics import AnimatePhysics as AnimatePhysics
from .._pyi.animations.animate_set import AnimateSet as AnimateSet
from .._pyi.animations.audio import Audio as Audio
from .._pyi.animations.command import Command as Command
from .._pyi.animations.event import Event as Event
from .._pyi.animations.iterate_container import IterateContainer as IterateContainer
from .._pyi.animations.parallel_time_container import ParallelTimeContainer as ParallelTimeContainer
from .._pyi.animations.sequence_time_container import SequenceTimeContainer as SequenceTimeContainer
from .._pyi.animations.target_properties import TargetProperties as TargetProperties
from .._pyi.animations.time_filter_pair import TimeFilterPair as TimeFilterPair
from .._pyi.animations.value_pair import ValuePair as ValuePair
from .._pyi.animations.x_animate import XAnimate as XAnimate
from .._pyi.animations.x_animate_color import XAnimateColor as XAnimateColor
from .._pyi.animations.x_animate_motion import XAnimateMotion as XAnimateMotion
from .._pyi.animations.x_animate_physics import XAnimatePhysics as XAnimatePhysics
from .._pyi.animations.x_animate_set import XAnimateSet as XAnimateSet
from .._pyi.animations.x_animate_transform import XAnimateTransform as XAnimateTransform
from .._pyi.animations.x_animation_listener import XAnimationListener as XAnimationListener
from .._pyi.animations.x_animation_node import XAnimationNode as XAnimationNode
from .._pyi.animations.x_animation_node_supplier import XAnimationNodeSupplier as XAnimationNodeSupplier
from .._pyi.animations.x_audio import XAudio as XAudio
from .._pyi.animations.x_command import XCommand as XCommand
from .._pyi.animations.x_iterate_container import XIterateContainer as XIterateContainer
from .._pyi.animations.x_parallel_time_container import XParallelTimeContainer as XParallelTimeContainer
from .._pyi.animations.x_time_container import XTimeContainer as XTimeContainer
from .._pyi.animations.x_transition_filter import XTransitionFilter as XTransitionFilter



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .._pyi.form.control_font_dialog import ControlFontDialog as ControlFontDialog
from .._pyi.form.data_aware_control_model import DataAwareControlModel as DataAwareControlModel
from .._pyi.form.database_delete_event import DatabaseDeleteEvent as DatabaseDeleteEvent
from .._pyi.form.database_parameter_event import DatabaseParameterEvent as DatabaseParameterEvent
from .._pyi.form.error_event import ErrorEvent as ErrorEvent
from .._pyi.form.form_component import FormComponent as FormComponent
from .._pyi.form.form_components import FormComponents as FormComponents
from .._pyi.form.form_control_model import FormControlModel as FormControlModel
from .._pyi.form.form_controller import FormController as FormController
from .._pyi.form.form_controller_dispatcher import FormControllerDispatcher as FormControllerDispatcher
from .._pyi.form.forms import Forms as Forms
from .._pyi.form.property_browser_controller import PropertyBrowserController as PropertyBrowserController
from .._pyi.form.tab_order_dialog import TabOrderDialog as TabOrderDialog
from .._pyi.form.x_approve_action_broadcaster import XApproveActionBroadcaster as XApproveActionBroadcaster
from .._pyi.form.x_approve_action_listener import XApproveActionListener as XApproveActionListener
from .._pyi.form.x_bound_component import XBoundComponent as XBoundComponent
from .._pyi.form.x_bound_control import XBoundControl as XBoundControl
from .._pyi.form.x_change_broadcaster import XChangeBroadcaster as XChangeBroadcaster
from .._pyi.form.x_change_listener import XChangeListener as XChangeListener
from .._pyi.form.x_confirm_delete_broadcaster import XConfirmDeleteBroadcaster as XConfirmDeleteBroadcaster
from .._pyi.form.x_confirm_delete_listener import XConfirmDeleteListener as XConfirmDeleteListener
from .._pyi.form.x_database_parameter_broadcaster import XDatabaseParameterBroadcaster as XDatabaseParameterBroadcaster
from .._pyi.form.x_database_parameter_broadcaster2 import XDatabaseParameterBroadcaster2 as XDatabaseParameterBroadcaster2
from .._pyi.form.x_database_parameter_listener import XDatabaseParameterListener as XDatabaseParameterListener
from .._pyi.form.x_delete_listener import XDeleteListener as XDeleteListener
from .._pyi.form.x_error_broadcaster import XErrorBroadcaster as XErrorBroadcaster
from .._pyi.form.x_error_listener import XErrorListener as XErrorListener
from .._pyi.form.x_form import XForm as XForm
from .._pyi.form.x_form_component import XFormComponent as XFormComponent
from .._pyi.form.x_form_controller import XFormController as XFormController
from .._pyi.form.x_form_controller_listener import XFormControllerListener as XFormControllerListener
from .._pyi.form.x_forms import XForms as XForms
from .._pyi.form.x_forms_supplier import XFormsSupplier as XFormsSupplier
from .._pyi.form.x_forms_supplier2 import XFormsSupplier2 as XFormsSupplier2
from .._pyi.form.x_grid import XGrid as XGrid
from .._pyi.form.x_grid_column_factory import XGridColumnFactory as XGridColumnFactory
from .._pyi.form.x_grid_control import XGridControl as XGridControl
from .._pyi.form.x_grid_control_listener import XGridControlListener as XGridControlListener
from .._pyi.form.x_grid_field_data_supplier import XGridFieldDataSupplier as XGridFieldDataSupplier
from .._pyi.form.x_grid_peer import XGridPeer as XGridPeer
from .._pyi.form.x_image_producer_supplier import XImageProducerSupplier as XImageProducerSupplier
from .._pyi.form.x_insert_listener import XInsertListener as XInsertListener
from .._pyi.form.x_load_listener import XLoadListener as XLoadListener
from .._pyi.form.x_loadable import XLoadable as XLoadable
from .._pyi.form.x_positioning_listener import XPositioningListener as XPositioningListener
from .._pyi.form.x_reset import XReset as XReset
from .._pyi.form.x_reset_listener import XResetListener as XResetListener
from .._pyi.form.x_restore_listener import XRestoreListener as XRestoreListener
from .._pyi.form.x_submit import XSubmit as XSubmit
from .._pyi.form.x_submit_listener import XSubmitListener as XSubmitListener
from .._pyi.form.x_update_broadcaster import XUpdateBroadcaster as XUpdateBroadcaster
from .._pyi.form.x_update_listener import XUpdateListener as XUpdateListener



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.drawing.framework
import typing
from .x_resource_factory import XResourceFactory as XResourceFactory_b3561268
if typing.TYPE_CHECKING:
    from ...frame.x_controller import XController as XController_b00e0b8f

class BasicViewFactory(XResourceFactory_b3561268):
    """
    Service Class

    The BasicViewFactory is a view factory that provides the panes used by the Draw and Impress applications.
    
    The factory recognizes the following URLs:

    See Also:
        `API BasicViewFactory <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1BasicViewFactory.html>`_
    """
    def create(self, xController: 'XController_b00e0b8f') -> None:
        """
        Give the controller to new instances so that they have access to the drawing framework controllers.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing


class FolderListEntry(object):
    """
    Struct Class

    Information about a single folder in a FolderList.

    See Also:
        `API FolderListEntry <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1FolderListEntry.html>`_
    """
    typeName: Literal['com.sun.star.ucb.FolderListEntry']

    def __init__(self, Title: typing.Optional[str] = ..., ID: typing.Optional[str] = ..., Subscribed: typing.Optional[bool] = ..., New: typing.Optional[bool] = ..., Removed: typing.Optional[bool] = ..., Purge: typing.Optional[bool] = ...) -> None:
        """
        Constructor

        Arguments:
            Title (str, optional): Title value.
            ID (str, optional): ID value.
            Subscribed (bool, optional): Subscribed value.
            New (bool, optional): New value.
            Removed (bool, optional): Removed value.
            Purge (bool, optional): Purge value.
        """


    @property
    def Title(self) -> str:
        """
        The title of the folder.
        """


    @property
    def ID(self) -> str:
        """
        A (unique) identifier for the folder (used by IMAP, where different folders with equal human-readable titles may exist; otherwise, it may be left empty).
        """


    @property
    def Subscribed(self) -> bool:
        """
        The folder is subscribed.
        """


    @property
    def New(self) -> bool:
        """
        The folder is new.
        """


    @property
    def Removed(self) -> bool:
        """
        The folder has been removed.
        """


    @property
    def Purge(self) -> bool:
        """
        The folder shall be purged (only used in conjunction with the FolderListCommand.SET).
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing


class RuleTerm(object):
    """
    Struct Class

    describes a term.
    
    A term is used to select objects to which a rule should apply.

    See Also:
        `API RuleTerm <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1RuleTerm.html>`_
    """
    typeName: Literal['com.sun.star.ucb.RuleTerm']

    def __init__(self, Property: typing.Optional[str] = ..., Operand: typing.Optional[object] = ..., Operator: typing.Optional[int] = ..., CaseSensitive: typing.Optional[bool] = ..., RegularExpression: typing.Optional[bool] = ...) -> None:
        """
        Constructor

        Arguments:
            Property (str, optional): Property value.
            Operand (object, optional): Operand value.
            Operator (int, optional): Operator value.
            CaseSensitive (bool, optional): CaseSensitive value.
            RegularExpression (bool, optional): RegularExpression value.
        """


    @property
    def Property(self) -> str:
        """
        the name of the property used to match the term.
        """


    @property
    def Operand(self) -> object:
        """
        the value of the property used to compare with the document property.
        """


    @property
    def Operator(self) -> int:
        """
        the operator used to compare the property of the document with the given value (e.g.
        
        \"contains\" or \"greater equal\").
        
        The value can be one of the RuleOperator constants.
        """


    @property
    def CaseSensitive(self) -> bool:
        """
        this flag indicates whether a string \"operand\" shall be compared case sensitive.
        """


    @property
    def RegularExpression(self) -> bool:
        """
        this flag indicates whether a string \"operand\" shall be treated as a regular expression.
        """


